@@ -1,13 +1,13 @@
 
 #' @title Cost Matrix for two-dimensional Optimal Transport
-#' @description Calculate the cost matrix for the optimal transport between two-dimensional grids with respect to the cost function 
+#' @description Calculate the cost matrix for the optimal transport between two-dimensional grids with respect to the cost function
 #' \deqn{c(x, y) = | x_1 - y_1 |^{p_1} + | x_2 - y_2 |^{p_2}.}
 #' @param ... further arguments (currently unused).
-#' @return a matrix giving the pairwise costs in column-mayor format. 
+#' @return a matrix giving the pairwise costs in column-mayor format.
 #' @examples
 #' x <- otgrid(cbind(0:1, 1:0))
 #' y <- otgrid(cbind(1:0, 0:1))
-#' 
+#'
 #' transport_costmat(x, y, p.1 = 1, p.2 = 3)
 #' @export
 transport_costmat <- \(x, ...) {
@@ -25,8 +25,8 @@ transport_costmat.otgrid <- \(x, y, p.1 = 2, p.2 = p.1, ...) {
 
 	stopifnot(inherits(y, "otgrid"))
 	stopifnot(is.numeric(p.1) && is.numeric(p.2) && isTRUE(p.1 >= 1) && isTRUE(p.2 >= 1))
-	
-	costMatrix(x$x, x$y, y$x, y$x, p.1, p.2)
+
+	costMatrix(x$x, x$y, y$x, y$y, p.1, p.2)
 }
 
 #' @rdname transport_costmat
